==> hardcoretotemnerf-3.0.0%2B1.21.4-fabric-sources.jar: dev/spagurder/htn/mixin/NotchAppleMixin.java <==
package dev.spagurder.htn.mixin;

import dev.spagurder.htn.Config;
import dev.spagurder.htn.HardcoreTotemNerf;
import dev.spagurder.htn.data.HTNState;
import dev.spagurder.htn.data.PlayerData;
import net.minecraft.class_1309;
import net.minecraft.class_1324;
import net.minecraft.class_1802;
import net.minecraft.class_3222;
import net.minecraft.class_5134;
import org.spongepowered.asm.mixin.Mixin;
import org.spongepowered.asm.mixin.injection.At;
import org.spongepowered.asm.mixin.injection.Inject;
import org.spongepowered.asm.mixin.injection.callback.CallbackInfo;

@Mixin(class_1309.class)
public class NotchAppleMixin {

    @Inject(method = "completeUsingItem", at = @At("HEAD"))
    private void afterCompleteUsingItem(CallbackInfo ci) {
        class_1309 entity = (class_1309) (Object) this;
        if (Config.notchAppleRestoresMaxHealth) {
            if (entity instanceof class_3222 player) {
                if (player.method_6030().method_31574(class_1802.field_8367)) {
                    class_1324 maxHealthAttribute = player.method_5996(class_5134.field_23716);
                    if (maxHealthAttribute == null) {
                        HardcoreTotemNerf.LOGGER.error("MAX_HEALTH attribute missing from player {}", player.method_5667());
                        return;
                    }
                    PlayerData playerData = HTNState.playerState.get(player.method_5667());
                    float restorationAmount = Config.restorationTracking
                            ? Math.min(playerData.maxHealthDeficit, Config.maxHealthRestorationAmount)
                            : Config.maxHealthRestorationAmount;
                    float maxHealth = player.method_6063() + restorationAmount;
                    if (!(Config.restorationTracking && Config.trackingOverridesMaxHealthCap)) {
                        maxHealth = Math.min(maxHealth, Config.maximumMaxHealth);
                    }
                    if (maxHealth > player.method_6063()) {
                        if (maxHealth == Config.maximumMaxHealth) {
                            playerData.maxHealthDeficit = 0f;
                        } else {
                            playerData.maxHealthDeficit += player.method_6063() - maxHealth;
                        }
                        maxHealthAttribute.method_6192(maxHealth);
                        HTNState.savePlayerData(player.method_5667());
                    }
                }
            }
        }
    }

}

==> hardcoretotemnerf-3.1.0%2B1.21.4-fabric-sources.jar: dev/spagurder/htn/mixin/NotchAppleMixin.java <==
package dev.spagurder.htn.mixin;

import dev.spagurder.htn.Config;
import dev.spagurder.htn.HardcoreTotemNerf;
import dev.spagurder.htn.data.HTNState;
import dev.spagurder.htn.data.PlayerData;
import net.minecraft.class_1309;
import net.minecraft.class_1324;
import net.minecraft.class_1802;
import net.minecraft.class_3222;
import net.minecraft.class_5134;
import org.spongepowered.asm.mixin.Mixin;
import org.spongepowered.asm.mixin.injection.At;
import org.spongepowered.asm.mixin.injection.Inject;
import org.spongepowered.asm.mixin.injection.callback.CallbackInfo;

@Mixin(class_1309.class)
public class NotchAppleMixin {

    @Inject(method = "completeUsingItem", at = @At("HEAD"))
    private void afterCompleteUsingItem(CallbackInfo ci) {
        class_1309 entity = (class_1309) (Object) this;
        if (Config.notchAppleRestoresMaxHealth) {
            if (entity instanceof class_3222 player) {
                if (player.method_6030().method_31574(class_1802.field_8367)) {
                    class_1324 maxHealthAttribute = player.method_5996(class_5134.field_23716);
                    if (maxHealthAttribute == null) {
                        HardcoreTotemNerf.LOGGER.error("MAX_HEALTH attribute missing from player {}", player.method_5667());
                        return;
                    }
                    PlayerData playerData = HTNState.playerState.get(player.method_5667());
                    float restorationAmount = Config.restorationTracking
                            ? Math.min(playerData.maxHealthDeficit, Config.maxHealthRestorationAmount)
                            : Config.maxHealthRestorationAmount;
                    float maxHealth = player.method_6063() + restorationAmount;
                    if (!(Config.restorationTracking && Config.trackingOverridesMaxHealthCap)) {
                        maxHealth = Math.min(maxHealth, Config.maximumMaxHealth);
                    }
                    if (maxHealth > player.method_6063()) {
                        if (maxHealth == Config.maximumMaxHealth) {
                            playerData.maxHealthDeficit = 0f;
                        } else {
                            playerData.maxHealthDeficit += player.method_6063() - maxHealth;
                        }
                        maxHealthAttribute.method_6192(maxHealth);
                        HTNState.savePlayerData(player);
                    }
                }
            }
        }
    }

}
